@@ -39,7 +39,6 @@ const Application = imports.application;
 const ChangeMonitor = imports.changeMonitor;
 const Manager = imports.manager;
 const Notifications = imports.notifications;
-const Path = imports.path;
 const Query = imports.query;
 const Search = imports.search;
 const TrackerUtils = imports.trackerUtils;
@@ -563,7 +562,7 @@ const DocCommon = new Lang.Class({
         if (this._thumbPath) {
             let [ slice, border ] = Utils.getThumbnailFrameBorder();
             thumbnailedPixbuf = Gd.embed_image_in_frame(emblemedPixbuf,
-                'resource:///org/gnome/documents/thumbnail-frame.png',
+                'resource:///org/gnome/Documents/ui/thumbnail-frame.png',
                 slice, border);
         } else {
             thumbnailedPixbuf = emblemedPixbuf;
@@ -740,7 +739,7 @@ const LocalDocument = new Lang.Class({
     },
 
     canEdit: function() {
-        return false;
+        return this.collection;
     },
 
     canShare: function() {
@@ -783,7 +782,7 @@ const GoogleDocument = new Lang.Class({
         this.sourceName = _("Google");
     },
 
-    _createGDataEntry: function(cancellable, callback) {
+    createGDataEntry: function(cancellable, callback) {
         let source = Application.sourceManager.getItemById(this.resourceUrn);
 
         let authorizer = new GData.GoaAuthorizer({ goa_object: source.object });
@@ -810,7 +809,7 @@ const GoogleDocument = new Lang.Class({
     },
 
     load: function(passwd, cancellable, callback) {
-        this._createGDataEntry(cancellable, Lang.bind(this,
+        this.createGDataEntry(cancellable, Lang.bind(this,
             function(entry, service, exception) {
                 if (exception) {
                     // try loading from the most recent cache, if any
@@ -842,7 +841,7 @@ const GoogleDocument = new Lang.Class({
     },
 
     createThumbnail: function(callback) {
-        this._createGDataEntry(null, Lang.bind(this,
+        this.createGDataEntry(null, Lang.bind(this,
             function(entry, service, exception) {
                 if (exception) {
                     callback(false);
@@ -921,7 +920,7 @@ const GoogleDocument = new Lang.Class({
     },
 
     canEdit: function() {
-        return true;
+        return !this.collection;
     },
 
     canShare: function() {
