@@ -360,7 +360,8 @@ const CollectionRow = new Lang.Class({
         else
             menu.append(_("Rename…"), 'dialog.action-disabled');
 
-        if (this.collection.canTrash())
+        let activeCollection = Application.documentManager.getActiveCollection();
+        if (this.collection.canTrash() && this.collection != activeCollection)
             menu.append(_("Delete"), 'dialog.delete-collection(\'' + this.collection.id + '\')');
         else
             menu.append(_("Delete"), 'dialog.action-disabled');
@@ -525,14 +526,14 @@ const CollectionList = new Lang.Class({
         this.connect('destroy', Lang.bind(this,
             function() {
                 let rows = this.get_children();
-		rows.forEach(function(row) {
-		    let currentView = row.views.get_visible_child_name();
-		    if (currentView == CollectionRowViews.DELETE) {
-		        row.deleteCollection();
-		    }
+                rows.forEach(function(row) {
+                    let currentView = row.views.get_visible_child_name();
+                    if (currentView == CollectionRowViews.DELETE) {
+                        row.deleteCollection();
+                    }
                 });
-		Application.documentManager.disconnect(collAddedId);
-		Application.documentManager.disconnect(collRemovedId);
+                Application.documentManager.disconnect(collAddedId);
+                Application.documentManager.disconnect(collRemovedId);
             }));
 
         // populate the list
@@ -753,9 +754,9 @@ const OrganizeCollectionDialog = new Lang.Class({
             this._addButtonEmpty.grab_default();
         } else {
             this._content.set_visible_child(this._viewCollections);
-	    this._addEntryCollections.grab_focus();
-	    this._addButtonCollections.grab_default();
-	}
+            this._addEntryCollections.grab_focus();
+            this._addButtonCollections.grab_default();
+        }
     },
 
     _setRenameMode: function(renameMode) {
@@ -887,6 +888,10 @@ const SelectionToolbar = new Lang.Class({
         this._toolbarCollection = new Gtk.Button({ label: _("Collections") });
         toolbar.pack_end(this._toolbarCollection);
         this._toolbarCollection.connect('clicked', Lang.bind(this, this._onToolbarCollection));
+        Application.modeController.connect('window-mode-changed',
+            Lang.bind(this, this._updateCollectionsButton));
+        Application.documentManager.connect('active-collection-changed',
+            Lang.bind(this, this._updateCollectionsButton));
 
         this.show_all();
 
@@ -896,6 +901,15 @@ const SelectionToolbar = new Lang.Class({
             Lang.bind(this, this._onSelectionChanged));
     },
 
+    _updateCollectionsButton: function() {
+        let windowMode = Application.modeController.getWindowMode();
+        let activeCollection = Application.documentManager.getActiveCollection();
+        if (windowMode == WindowMode.WindowMode.COLLECTIONS && !activeCollection)
+            this._toolbarCollection.hide();
+        else
+            this._toolbarCollection.show();
+    },
+
     _onSelectionModeChanged: function(controller, mode) {
         if (mode)
             this._onSelectionChanged();
